@@ -11,11 +11,17 @@ from jupyter_ascending.extension import load_jupyter_server_extension
 from jupyter_ascending.nbextension import _jupyter_nbextension_paths
 from jupyter_ascending.widget import SyncWidget
 
+
+def _jupyter_server_extension_paths():
+    return []
+
+
 __all__ = [
     "SyncWidget",
     "__version__",
     "_jupyter_nbextension_paths",
     "load_ipython_extension",
+    "_jupyter_server_extension_paths",
     "load_jupyter_server_extension",
     "version_info",
 ]
