@@ -2,7 +2,7 @@ import argparse
 from functools import partial
 from pathlib import Path
 
-from jupyter_ascending import server_multiplexer
+from jupyter_ascending.handlers import jupyter_server
 from jupyter_ascending.json_requests import ExecuteRequest
 
 
@@ -21,11 +21,11 @@ def send(file_name: str, line_number: int, *args, **kwargs):
 
             # No need to loop through the whole file, just execute when we get there
             if index == int(arguments.linenumber):
-                server_multiplexer.request_notebook_command(request_obj(cell_index=cell_index))
+                jupyter_server.request_notebook_command(request_obj(cell_index=cell_index))
 
                 return
 
-    server_multiplexer.request_notebook_command(request_obj(cell_index=cell_index))
+    jupyter_server.request_notebook_command(request_obj(cell_index=cell_index))
 
 
 if __name__ == "__main__":
